==> google_cloud_life_sciences-0.4.1-py2.py3-none-any.whl: google/cloud/lifesciences/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from google.cloud.lifesciences_v2beta.services.workflows_service_v2_beta.client import (
    WorkflowsServiceV2BetaClient,
)
from google.cloud.lifesciences_v2beta.services.workflows_service_v2_beta.async_client import (
    WorkflowsServiceV2BetaAsyncClient,
)

from google.cloud.lifesciences_v2beta.types.workflows import Accelerator
from google.cloud.lifesciences_v2beta.types.workflows import Action
from google.cloud.lifesciences_v2beta.types.workflows import ContainerKilledEvent
from google.cloud.lifesciences_v2beta.types.workflows import ContainerStartedEvent
from google.cloud.lifesciences_v2beta.types.workflows import ContainerStoppedEvent
from google.cloud.lifesciences_v2beta.types.workflows import DelayedEvent
from google.cloud.lifesciences_v2beta.types.workflows import Disk
from google.cloud.lifesciences_v2beta.types.workflows import Event
from google.cloud.lifesciences_v2beta.types.workflows import ExistingDisk
from google.cloud.lifesciences_v2beta.types.workflows import FailedEvent
from google.cloud.lifesciences_v2beta.types.workflows import Metadata
from google.cloud.lifesciences_v2beta.types.workflows import Mount
from google.cloud.lifesciences_v2beta.types.workflows import Network
from google.cloud.lifesciences_v2beta.types.workflows import NFSMount
from google.cloud.lifesciences_v2beta.types.workflows import PersistentDisk
from google.cloud.lifesciences_v2beta.types.workflows import Pipeline
from google.cloud.lifesciences_v2beta.types.workflows import PullStartedEvent
from google.cloud.lifesciences_v2beta.types.workflows import PullStoppedEvent
from google.cloud.lifesciences_v2beta.types.workflows import Resources
from google.cloud.lifesciences_v2beta.types.workflows import RunPipelineRequest
from google.cloud.lifesciences_v2beta.types.workflows import RunPipelineResponse
from google.cloud.lifesciences_v2beta.types.workflows import Secret
from google.cloud.lifesciences_v2beta.types.workflows import ServiceAccount
from google.cloud.lifesciences_v2beta.types.workflows import UnexpectedExitStatusEvent
from google.cloud.lifesciences_v2beta.types.workflows import VirtualMachine
from google.cloud.lifesciences_v2beta.types.workflows import Volume
from google.cloud.lifesciences_v2beta.types.workflows import WorkerAssignedEvent
from google.cloud.lifesciences_v2beta.types.workflows import WorkerReleasedEvent

__all__ = (
    "WorkflowsServiceV2BetaClient",
    "WorkflowsServiceV2BetaAsyncClient",
    "Accelerator",
    "Action",
    "ContainerKilledEvent",
    "ContainerStartedEvent",
    "ContainerStoppedEvent",
    "DelayedEvent",
    "Disk",
    "Event",
    "ExistingDisk",
    "FailedEvent",
    "Metadata",
    "Mount",
    "Network",
    "NFSMount",
    "PersistentDisk",
    "Pipeline",
    "PullStartedEvent",
    "PullStoppedEvent",
    "Resources",
    "RunPipelineRequest",
    "RunPipelineResponse",
    "Secret",
    "ServiceAccount",
    "UnexpectedExitStatusEvent",
    "VirtualMachine",
    "Volume",
    "WorkerAssignedEvent",
    "WorkerReleasedEvent",
)

==> google_cloud_life_sciences-0.6.0-py2.py3-none-any.whl: google/cloud/lifesciences/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from google.cloud.lifesciences_v2beta.services.workflows_service_v2_beta.async_client import (
    WorkflowsServiceV2BetaAsyncClient,
)
from google.cloud.lifesciences_v2beta.services.workflows_service_v2_beta.client import (
    WorkflowsServiceV2BetaClient,
)
from google.cloud.lifesciences_v2beta.types.workflows import (
    Accelerator,
    Action,
    ContainerKilledEvent,
    ContainerStartedEvent,
    ContainerStoppedEvent,
    DelayedEvent,
    Disk,
    Event,
    ExistingDisk,
    FailedEvent,
    Metadata,
    Mount,
    Network,
    NFSMount,
    PersistentDisk,
    Pipeline,
    PullStartedEvent,
    PullStoppedEvent,
    Resources,
    RunPipelineRequest,
    RunPipelineResponse,
    Secret,
    ServiceAccount,
    UnexpectedExitStatusEvent,
    VirtualMachine,
    Volume,
    WorkerAssignedEvent,
    WorkerReleasedEvent,
)

__all__ = (
    "WorkflowsServiceV2BetaClient",
    "WorkflowsServiceV2BetaAsyncClient",
    "Accelerator",
    "Action",
    "ContainerKilledEvent",
    "ContainerStartedEvent",
    "ContainerStoppedEvent",
    "DelayedEvent",
    "Disk",
    "Event",
    "ExistingDisk",
    "FailedEvent",
    "Metadata",
    "Mount",
    "Network",
    "NFSMount",
    "PersistentDisk",
    "Pipeline",
    "PullStartedEvent",
    "PullStoppedEvent",
    "Resources",
    "RunPipelineRequest",
    "RunPipelineResponse",
    "Secret",
    "ServiceAccount",
    "UnexpectedExitStatusEvent",
    "VirtualMachine",
    "Volume",
    "WorkerAssignedEvent",
    "WorkerReleasedEvent",
)
